@@ -20,6 +20,7 @@
 #define SDLKEYS_H
 
 extern char sdlkeys[1024][2][128];
+extern bool sdlkeys_iskeyboard[1024];
 extern char xb360buttons[10][128];
 extern char xbox360axes[10][128];
 extern char xb360dpad[128];
@@ -30,5 +31,6 @@ extern char controllerup[128];
 extern char controllerdown[128];
 extern char controllerleft[128];
 extern char controllerright[128];
+extern char unboundcontrol[128];
 
 #endif
