@@ -834,14 +834,24 @@ processAction (ShowReplay rname) = do
     let (teams', params1, params2, roundMsgs') = fromJust cInfo
 
     when (isJust cInfo) $ do
-        mapM_ processAction $ concat [
-            [AnswerClients [c] ["JOINED", nick cl]]
-            , answerFullConfigParams cl params1 params2
-            , answerAllTeams cl teams'
-            , [AnswerClients [c]  ["RUN_GAME"]]
-            , [AnswerClients [c] $ "EM" : roundMsgs']
-            , [AnswerClients [c] ["KICKED"]]
-            ]
+        mapM_ processAction $
+            if clientProto cl < 58 then
+                concat [
+                    [AnswerClients [c] ["JOINED", nick cl]]
+                    , answerFullConfigParams cl params1 params2
+                    , answerAllTeams cl teams'
+                    , [AnswerClients [c]  ["RUN_GAME"]]
+                    , [AnswerClients [c] $ "EM" : roundMsgs']
+                    , [AnswerClients [c] ["KICKED"]]
+                ]
+            else
+                concat [
+                    [AnswerClients [c] ["REPLAY_START"]]
+                    , answerFullConfigParams cl params1 params2
+                    , answerAllTeams cl teams'
+                    , [AnswerClients [c]  ["RUN_GAME"]]
+                    , [AnswerClients [c] $ "EM" : roundMsgs']
+                ]
 
 processAction (SaveRoom rname) = do
     rnc <- gets roomsClients
@@ -852,7 +862,7 @@ processAction (SaveRoom rname) = do
 processAction (LoadRoom rname) = do
     Right (g, rs) <- io $ YAML.decodeFileEither (B.unpack rname)
     processAction $ ModifyRoom $ \r -> r{greeting = g, roomSaves = rs}
-	
+
 #else
 processAction SaveReplay = return ()
 processAction CheckRecord = return ()
@@ -860,8 +870,8 @@ processAction (CheckFailed _) = return ()
 processAction (CheckSuccess _) = return ()
 processAction (QueryReplay _) = processAction $ Warning $ loc "This server does not support replays!"
 processAction (ShowReplay rname) = return ()
-processAction (SaveRoom rname) = return ()
-processAction (LoadRoom rname) = return ()
+processAction (SaveRoom rname) = return () -- TODO: Send warning that this command is unsupported
+processAction (LoadRoom rname) = return () -- TODO: Send warning that this command is unsupported
 #endif
 
 processAction Cleanup = do
@@ -885,3 +895,13 @@ processAction (ReactCmd cmd) = do
 
 processAction CheckVotes =
     checkVotes >>= mapM_ processAction
+
+processAction (ShowRegisteredOnlyState chans) = do
+    si <- gets serverInfo
+    processAction $ AnswerClients chans
+        ["CHAT", nickServer,
+        if isRegisteredUsersOnly si then
+            loc "This server no longer allows unregistered players to join."
+        else
+            loc "This server now allows unregistered players to join."
+        ]
