@@ -32,7 +32,7 @@
 #endif
 
 #if TARGET_SDL13
-static SDLCALL Sint64 physfsrwops_size(struct SDL_RWops *rw)
+static Sint64 SDLCALL physfsrwops_size(struct SDL_RWops *rw)
 {
     PHYSFS_File *handle = (PHYSFS_File *) rw->hidden.unknown.data1;
     return PHYSFS_fileLength(handle);
@@ -40,7 +40,7 @@ static SDLCALL Sint64 physfsrwops_size(struct SDL_RWops *rw)
 #endif
 
 #if TARGET_SDL13
-static SDLCALL Sint64 physfsrwops_seek(struct SDL_RWops *rw, Sint64 offset, int whence)
+static Sint64 SDLCALL physfsrwops_seek(struct SDL_RWops *rw, Sint64 offset, int whence)
 #else
 static int physfsrwops_seek(SDL_RWops *rw, int offset, int whence)
 #endif
@@ -56,7 +56,7 @@ static int physfsrwops_seek(SDL_RWops *rw, int offset, int whence)
         if (current == -1)
         {
             SDL_SetError("Can't find position in file: %s",
-                          PHYSFS_getLastError());
+                          PHYSFS_getErrorByCode(PHYSFS_getLastErrorCode()));
             return -1;
         } /* if */
 
@@ -77,7 +77,7 @@ static int physfsrwops_seek(SDL_RWops *rw, int offset, int whence)
         const PHYSFS_sint64 len = PHYSFS_fileLength(handle);
         if (len == -1)
         {
-            SDL_SetError("Can't find end of file: %s", PHYSFS_getLastError());
+            SDL_SetError("Can't find end of file: %s", PHYSFS_getErrorByCode(PHYSFS_getLastErrorCode()));
             return -1;
         } /* if */
 
@@ -98,7 +98,7 @@ static int physfsrwops_seek(SDL_RWops *rw, int offset, int whence)
 
     if (!PHYSFS_seek(handle, (PHYSFS_uint64) pos))
     {
-        SDL_SetError("PhysicsFS error: %s", PHYSFS_getLastError());
+        SDL_SetError("PhysicsFS error: %s", PHYSFS_getErrorByCode(PHYSFS_getLastErrorCode()));
         return -1;
     } /* if */
 
@@ -123,7 +123,7 @@ static int physfsrwops_read(SDL_RWops *rw, void *ptr, int size, int maxnum)
     if (rc != ((PHYSFS_sint64) readlen))
     {
         if (!PHYSFS_eof(handle)) /* not EOF? Must be an error. */
-            SDL_SetError("PhysicsFS error: %s", PHYSFS_getLastError());
+            SDL_SetError("PhysicsFS error: %s", PHYSFS_getErrorByCode(PHYSFS_getLastErrorCode()));
     } /* if */
 
     #if TARGET_SDL13
@@ -145,7 +145,7 @@ static int physfsrwops_write(SDL_RWops *rw, const void *ptr, int size, int num)
     const PHYSFS_uint64 writelen = (PHYSFS_uint64) (num * size);
     const PHYSFS_sint64 rc = PHYSFS_writeBytes(handle, ptr, writelen);
     if (rc != ((PHYSFS_sint64) writelen))
-        SDL_SetError("PhysicsFS error: %s", PHYSFS_getLastError());
+        SDL_SetError("PhysicsFS error: %s", PHYSFS_getErrorByCode(PHYSFS_getLastErrorCode()));
 
     #if TARGET_SDL13
     return (size_t) rc;
@@ -160,7 +160,7 @@ static int physfsrwops_close(SDL_RWops *rw)
     PHYSFS_File *handle = (PHYSFS_File *) rw->hidden.unknown.data1;
     if (!PHYSFS_close(handle))
     {
-        SDL_SetError("PhysicsFS error: %s", PHYSFS_getLastError());
+        SDL_SetError("PhysicsFS error: %s", PHYSFS_getErrorByCode(PHYSFS_getLastErrorCode()));
         return -1;
     } /* if */
 
@@ -174,7 +174,7 @@ static SDL_RWops *create_rwops(PHYSFS_File *handle)
     SDL_RWops *retval = NULL;
 
     if (handle == NULL)
-        SDL_SetError("PhysicsFS error: %s", PHYSFS_getLastError());
+        SDL_SetError("PhysicsFS error: %s", PHYSFS_getErrorByCode(PHYSFS_getLastErrorCode()));
     else
     {
         retval = SDL_AllocRW();
