@@ -1,7 +1,9 @@
+HedgewarsScriptLoad("/Scripts/Utils.lua")
 HedgewarsScriptLoad("/Scripts/Locale.lua")
 
 local hhs = {}
 local missionWon = nil
+local missionEndHandled = false
 local endTimer = 1000
 local hogsKilled = 0
 local finishTime
@@ -71,7 +73,7 @@ local HogData =	{
 
 				}
 
-local playerTeamName = loc("Wannabe Shoppsta")
+local playerTeamName
 
 function GetKillScore()
 	return math.ceil((hogsKilled / 16)*6000)
@@ -90,13 +92,15 @@ function GameOverMan()
 	valkyriesTimer = -1
 	missionWon = false
 	ProtectEnemies()
-	ShowMission(loc("Rope-knocking Challenge"), loc("Challenge over!"), loc("Oh no! Just try again!"), -amSkip, 0)
 	SendStat(siGameResult, loc("Challenge over!"))
 	local score = GetKillScore()
 	SendStat(siCustomAchievement, string.format(loc("You have killed %d of 16 hedgehogs (+%d points)."), hogsKilled, score))
-	SendStat(siPointType, loc("points"))
+	SendStat(siPointType, "!POINTS")
 	SendStat(siPlayerKills, tostring(score), playerTeamName)
-	PlaySound(sndHellish)
+
+	-- Update highscore
+	updateChallengeRecord("Highscore", score)
+
 	EndGame()
 end
 
@@ -112,10 +116,13 @@ function GG()
 
 	SendStat(siCustomAchievement, string.format(loc("You have killed %d of 16 hedgehogs (+%d points)."), hogsKilled, hogScore))
 	SendStat(siCustomAchievement, string.format(loc("You have completed this challenge in %.2f s (+%d points)."), completeTime, timeScore))
-	SendStat(siPointType, loc("points"))
+	SendStat(siPointType, "!POINTS")
 	SendStat(siPlayerKills, tostring(score), playerTeamName)
 	SetTeamLabel(playerTeamName, tostring(score))
 
+	-- Update highscore
+	updateChallengeRecord("Highscore", score)
+
 	if hhs[0] and GetHealth(hhs[0]) then
 		SetEffect(hhs[0], heInvulnerable, 1)
 	end
@@ -154,7 +161,6 @@ function onGameInit()
 	GameFlags = gfBorder + gfSolidLand
 
 	TurnTime = 180 * 1000
-	Delay = 500
 	Map = "Ropes"
 	Theme = "Eyes"
 
@@ -166,9 +172,8 @@ function onGameInit()
 	MinesNum = 0
 	Explosives = 0
 
-	AddTeam(playerTeamName, -1, "money", "Island", "Default", "cm_shoppa")
-	hhs[0] = AddHog(loc("Ace"), 0, 1, "Gasmask")
-	SetGearPosition(player, 1380, 1500)
+	playerTeamName = AddMissionTeam(-1)
+	hhs[0] = AddMissionHog(1)
 
 	AddTeam(loc("Unsuspecting Louts"), -2, "Simple", "Island", "Default", "cm_face")
 	for i = 1, 8 do
@@ -188,11 +193,17 @@ end
 function onGameStart()
 	SendHealthStatsOff()
 
+	local recordInfo = getReadableChallengeRecord("Highscore")
+	if recordInfo == nil then
+		recordInfo = ""
+	else
+		recordInfo = "|" .. recordInfo
+	end
 	ShowMission     (
                         loc("Rope-knocking Challenge"),
                         loc("Challenge"),
                         loc("Use the rope to knock your enemies to their doom.") .. "|" ..
-                        loc("Finish this challenge as fast as possible to earn bonus points."),
+                        loc("Finish this challenge as fast as possible to earn bonus points.").. recordInfo,
                         -amRope, 4000)
 	SetTeamLabel(playerTeamName, "0")
 
@@ -215,6 +226,7 @@ function onGameStart()
 	SetGearPosition(hhs[14], 3360, 659)
 	SetGearPosition(hhs[15], 3885, 285)
 	SetGearPosition(hhs[16], 935, 1160)
+	HogTurnLeft(hhs[0], true)
 
 	for i = 1, 16 do
 		AssignCharacter(i)
@@ -235,10 +247,12 @@ function onGameTick()
 			EndGame()
 		end
 
-		if missionWon == true then
-			AddCaption(loc("Victory!"), capcolDefault, capgrpGameState)
-		else
-			AddCaption(loc("Challenge over!"), capcolDefault, capgrpGameState)
+		if not missionEndHandled then
+			if missionWon == true then
+				SaveMissionVar("Won", "true")
+				AddCaption(loc("Victory!"), capcolDefault, capgrpGameState)
+			end
+			missionEndHandled = true
 		end
 
 	end
